# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtwebchannel-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtwebchannel   %mklibname qt%{qtmajor}webchannel %{qtmajor}
%define libqtwebchannel_d %mklibname qt%{qtmajor}webchannel -d

Name:           qtwebchannel5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebChannel component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtwebchannel
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Handle-signals-in-the-registered-object-s-thread.patch
Patch0002:      0002-Handle-per-transport-client-idle-status.patch
Patch0003:      0003-QMetaObjectPublisher-Never-send-stale-queued-message.patch

BuildRequires:  qtbase5-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}

Provides:       qt%{qtmajor}-qtwebchannel = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

%description
The Qt WebChannel module offers Qt applications a seamless way to publish QObjects
for interaction with HTML/JavaScript clients. These clients can either be inside
local Qt WebViews or any other, potentially remote, client which supports
JavaScript, as long as a communication channel such as WebSocket is available.

Qt WebChannel uses introspection on the QObjects and sends this serialized data
to the clients. There, with the help of a small JavaScript library, an object is
created which simulates the API of the QObject. Any invokable methods, including
slots, can be called as well as properties read and written. Additionally you can
connect to signals and register JavaScript callbacks as handlers.

%files
%{_qt5_qml}/QtWebChannel/
%{_qt5_examplesdir}/webchannel/

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtWebChannel%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtWebChannel%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtwebchannel.qch
%{_qt5_docdir}/qtwebchannel/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtwebchannel}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries

%description -n %{libqtwebchannel}
Qt%{qtmajor} Component Library.

%files -n %{libqtwebchannel}
%{_qt5_libdir}/libQt5WebChannel.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtwebchannel_d}
Summary:        Devel files needed to build apps based on QtWebChannel
Group:          Development/KDE and Qt
Requires:       %{libqtwebchannel} = %{version}
Provides:       libqtwebchannel5-devel = %{version}
Provides:       libqt5webchannel-devel = %{version}
Provides:       qtwebchannel5-devel = %{version}
Provides:       qt5webchannel-devel = %{version}

Provides:       libqtwebchannel-private-devel = %{version}
Provides:       libqtwebchannel5-private-devel = %{version}
Provides:       libqt5webchannel-private-devel = %{version}
Provides:       qtwebchannel-private-devel = %{version}
Provides:       qt5webchannel-private-devel = %{version}

%description -n %{libqtwebchannel_d}
Devel files needed to build apps based on QtWebChannel.

%files -n %{libqtwebchannel_d}
%{_qt5_libdir}/libQt5WebChannel.so
%{_qt5_libdir}/libQt5WebChannel.prl
%{_qt5_libdir}/pkgconfig/Qt5WebChannel.pc
%{_qt5_includedir}/QtWebChannel/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webchannel.pri
%{_qt5_libdir}/cmake/Qt5WebChannel/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webchannel_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtwebchannel-everywhere-src-%{qtversion}

%build
%qmake_qt5
%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif


%changelog
* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139647
- New version 5.15.16

* Tue Jan 09 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2029344
- New version 5.15.12

* Mon Dec 12 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1920821
- New version 5.15.7

* Sun Sep 11 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886985
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881283
- New version 5.15.5

* Mon Apr 04 2022 umeabot <umeabot> 5.15.2-2.mga9
+ Revision: 1843239
- Mageia 9 Mass Rebuild

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652480
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624927
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589840
- New version 5.15.0
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545570
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484415
- New version 5.14.1

* Sun Sep 08 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438508
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421126
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418167
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384597
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378554
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362299
- New version 5.12.1

* Thu Dec 13 2018 neoclust <neoclust> 5.12.0-2.mga7
+ Revision: 1341071
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319043
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300734
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245829
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232128
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216523
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205690
- New version 5.9.4

* Mon Dec 18 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1183201
- New version 5.9.3

* Sun Jul 16 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1123587
- New version 5.9.1

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-1.mga6
+ Revision: 1064869
- New version 5.6.2

* Fri Sep 02 2016 daviddavid <daviddavid> 5.6.1-3.mga6
+ Revision: 1049795
- build missing docs part (mga#9812)
- add qtwebchannel5-doc subpackage

* Sun Jul 03 2016 neoclust <neoclust> 5.6.1-2.mga6
+ Revision: 1038387
- Update to version 5.6.1-1
- New version

* Wed May 11 2016 akien <akien> 5.6.0-2.mga6
+ Revision: 1013633
- Fix libname s/qtwebchannel5/qt5webchannel5

* Thu Apr 21 2016 neoclust <neoclust> 5.6.0-1.mga6
+ Revision: 1004195
- New version 5.6.0

* Wed Mar 09 2016 neoclust <neoclust> 5.6.0-0.rc.2.mga6
+ Revision: 987943
- Rebuild Qt5 Stack to fix plasma crashes

* Sun Feb 28 2016 neoclust <neoclust> 5.6.0-0.rc.1.mga6
+ Revision: 980622
+ rebuild (emptylog)

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.4.mga6
+ Revision: 915943
- Rebuild against new cmake to have cmake() provides

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.3.mga6
+ Revision: 915786
- Rebuild against new cmake to have cmake() provides

* Mon Dec 21 2015 neoclust <neoclust> 5.6.0-0.beta.2.mga6
+ Revision: 912797
- Remove private devel packages

* Fri Dec 18 2015 neoclust <neoclust> 5.6.0-0.beta.1.mga6
+ Revision: 911707
- New version 5.6.0 Beta

* Tue Nov 10 2015 neoclust <neoclust> 5.5.1-2.mga6
+ Revision: 900378
- Rebuild against fixed qtbase5

* Fri Oct 23 2015 neoclust <neoclust> 5.5.1-1.mga6
+ Revision: 894507
- New version

* Sun Jul 12 2015 filipesaraiva <filipesaraiva> 5.5.0-1.mga6
+ Revision: 853391
- Update to Qt 5.5.0 version;
- Fix URL to new address qt.io;

* Tue Jun 23 2015 neoclust <neoclust> 5.5.0-0.rc.1.mga6
+ Revision: 839937
- New version 5.5 rc

* Tue Dec 23 2014 neoclust <neoclust> 5.4.0-1.mga5
+ Revision: 804997
- imported package qtwebchannel5

